package twostackqueue;

/**
 * A Dispenser is a container for objects.
 * New objects can be added with the add() method.
 * A dispenser selects one of its objects as the accessible object.
 * Each implementation determines its own policy for selecting the accessible
 * object.
 * This object is removed and returned by the remove() method.
 */
public interface Dispenser<T> {

  /**
   * d.add(t) adds t to d.
   * @param t the item to be added
   */
  public void add(T t);

  /**
   * d.isEmpty() returns true if d is empty.
   * @return
   */
  public boolean isEmpty();

  /**
   * d.remove() removes and returns an item in d.
   * The item returned is dependent on the implementation's policy.
   * @return an item
   */
  public T remove();

}
